==> index_now-1.0.8.tar.gz: index_now/tests/src/Unit/IndexNowKeyManagerTest.php <==
<?php

namespace Drupal\Tests\index_now\Unit;

use Drupal\Component\Uuid\UuidInterface;
use Drupal\Core\State\StateInterface;
use Drupal\index_now\Service\IndexNowKeyManager;
use Drupal\Tests\UnitTestCase;
use Prophecy\PhpUnit\ProphecyTrait;

/**
 * Tests the IndexNowKeyManager service.
 *
 * @coversDefaultClass \Drupal\index_now\Service\IndexNowKeyManager
 *
 * @group index_now
 */
class IndexNowKeyManagerTest extends UnitTestCase {

  use ProphecyTrait;

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();

    $this->state = $this->prophesize(StateInterface::class);
    $this->uuid = $this->prophesize(UuidInterface::class);

    $this->indexNowKeyManager = new IndexNowKeyManager(
      $this->state->reveal(),
      $this->uuid->reveal()
    );
  }

  /**
   * @covers ::getKey
   */
  public function testGetKeyIfNoApiKeySet(): void {
    $this->state->get($this->indexNowKeyManager::INDEXNOW_KEY_STATE_ID)
      ->ShouldBeCalled()
      ->willReturn(NULL);

    $key = $this->indexNowKeyManager->getKey();

    $this->assertTrue(is_string($key));
    $this->assertEmpty($key);
  }

  /**
   * @covers ::getKey
   */
  public function testGetKeyIfApiKeyExists(): void {
    $fake_uuid = 'ac48ac60-f99b-4d6c-9b5c-cb45fdee1048';

    $this->state->get($this->indexNowKeyManager::INDEXNOW_KEY_STATE_ID)
      ->ShouldBeCalled()
      ->willReturn($fake_uuid);

    $key = $this->indexNowKeyManager->getKey();
    $this->assertEquals($fake_uuid, $key);
  }

}

==> index_now-2.0.0.tar.gz: index_now/tests/src/Unit/IndexNowKeyManagerTest.php <==
<?php

namespace Drupal\Tests\index_now\Unit;

use Drupal\Component\Uuid\UuidInterface;
use Drupal\Core\State\StateInterface;
use Drupal\index_now\Service\IndexNowKeyManager;
use Drupal\Tests\UnitTestCase;
use Prophecy\PhpUnit\ProphecyTrait;

/**
 * Tests the IndexNowKeyManager service.
 *
 * @coversDefaultClass \Drupal\index_now\Service\IndexNowKeyManager
 *
 * @group index_now
 */
class IndexNowKeyManagerTest extends UnitTestCase {

  use ProphecyTrait;

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();

    $this->state = $this->prophesize(StateInterface::class);
    $this->uuid = $this->prophesize(UuidInterface::class);

    $this->indexNowKeyManager = new IndexNowKeyManager(
      $this->state->reveal(),
      $this->uuid->reveal()
    );
  }

  /**
   * @covers ::getKey
   */
  public function testGetKeyIfNoApiKeySet(): void {
    $this->state->get($this->indexNowKeyManager::INDEXNOW_KEY_STATE_ID)
      ->ShouldBeCalled()
      ->willReturn(NULL);

    $key = $this->indexNowKeyManager->getKey();

    $this->assertTrue(is_string($key));
    $this->assertEmpty($key);
  }

  /**
   * @covers ::getKey
   */
  public function testGetKeyIfApyKeyExists(): void {
    $fake_uuid = 'ac48ac60-f99b-4d6c-9b5c-cb45fdee1048';

    $this->state->get($this->indexNowKeyManager::INDEXNOW_KEY_STATE_ID)
      ->ShouldBeCalled()
      ->willReturn($fake_uuid);

    $key = $this->indexNowKeyManager->getKey();
    $this->assertEquals($fake_uuid, $key);
  }

}
